============
Installation
============

At the command line::

    $ easy_install django_cohort_analysis

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv django_cohort_analysis
    $ pip install django_cohort_analysis

After you have installed, add the project to Django's ::INSTALLED_APPS:: in ::settings.py::
